@@ -405,7 +405,7 @@ inline gboolean handle_list_keypress (GnomeCmdFileList *fl, GdkEventKey *event)
     switch (event->keyval)
     {
         case GDK_F3:
-            gnome_cmd_file_list_view (fl, -1);
+            gnome_cmd_file_list_view (fl, gnome_cmd_data.options.use_internal_viewer);
             return TRUE;
 
         case GDK_F4:
