@@ -2,7 +2,7 @@
  * @file gnome-cmd-main-menu.cc
  * @copyright (C) 2001-2006 Marcus Bjurman\n
  * @copyright (C) 2007-2012 Piotr Eljasiak\n
- * @copyright (C) 2013-2022 Uwe Scholz\n
+ * @copyright (C) 2013-2023 Uwe Scholz\n
  *
  * @copyright This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,19 +87,19 @@ add_menu_item (GnomeCmdMainMenu *main_menu,
     g_return_val_if_fail (GTK_IS_MENU_SHELL (menu), nullptr);
 
     GtkWidget *item, *label;
-    GtkWidget *pixmap_widget = nullptr;
+    GtkWidget *image_widget = nullptr;
 
     item = gtk_image_menu_item_new ();
 
     gtk_widget_set_tooltip_text (item, tooltip);
 
     if (pixmap && mask)
-        pixmap_widget = gtk_pixmap_new (pixmap, mask);
+        image_widget = gtk_image_new_from_pixmap (pixmap, mask);
 
-    if (pixmap_widget)
+    if (image_widget)
     {
-        gtk_widget_show (pixmap_widget);
-        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), pixmap_widget);
+        gtk_widget_show (image_widget);
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image_widget);
     }
 
     gtk_widget_show (item);
@@ -508,7 +508,7 @@ GtkType gnome_cmd_main_menu_get_type ()
 
 static void add_connection (GnomeCmdMainMenu *main_menu, GnomeCmdCon *con, const gchar *text, GnomeCmdPixmap *pixmap, GtkSignalFunc func)
 {
-    GtkMenuShell *connections_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->connections_menu)->submenu);
+    GtkMenuShell *connections_menu = GTK_MENU_SHELL (gtk_menu_item_get_submenu (GTK_MENU_ITEM (main_menu->priv->connections_menu)));
     GtkWidget *item;
 
     item = add_menu_item (main_menu, connections_menu, text, nullptr, pixmap?pixmap->pixmap:nullptr, pixmap?pixmap->mask:nullptr, func, con);
@@ -521,7 +521,7 @@ void gnome_cmd_main_menu_update_connections (GnomeCmdMainMenu *main_menu)
 {
     g_return_if_fail (GNOME_CMD_IS_MAIN_MENU (main_menu));
 
-    GtkMenuShell *connections_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->connections_menu)->submenu);
+    GtkMenuShell *connections_menu = GTK_MENU_SHELL (gtk_menu_item_get_submenu (GTK_MENU_ITEM (main_menu->priv->connections_menu)));
     GnomeCmdConList *con_list = gnome_cmd_con_list_get ();
     GList *all_cons = gnome_cmd_con_list_get_all (con_list);
     // GList *remote_cons = gnome_cmd_con_list_get_all_remote (con_list);
@@ -597,7 +597,7 @@ void gnome_cmd_main_menu_update_bookmarks (GnomeCmdMainMenu *main_menu)
     {
         GnomeCmdCon *con = GNOME_CMD_CON (cons->data);
         GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
-        GtkMenuShell *bookmarks_menu = GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->bookmarks_menu)->submenu);
+        GtkMenuShell *bookmarks_menu = GTK_MENU_SHELL (gtk_menu_item_get_submenu (GTK_MENU_ITEM (main_menu->priv->bookmarks_menu)));
         if (group && group->bookmarks)
         {
             // separator
@@ -631,7 +631,7 @@ static void on_plugin_menu_activate (GtkMenuItem *item, PluginData *data)
 
 void gnome_cmd_main_menu_add_plugin_menu (GnomeCmdMainMenu *main_menu, PluginData *pluginData)
 {
-    gtk_menu_shell_append (GTK_MENU_SHELL (GTK_MENU_ITEM (main_menu->priv->plugins_menu)->submenu), pluginData->menu);
+    gtk_menu_shell_append (GTK_MENU_SHELL (gtk_menu_item_get_submenu (GTK_MENU_ITEM (main_menu->priv->plugins_menu))), pluginData->menu);
 
     g_signal_connect (pluginData->menu, "activate", G_CALLBACK (on_plugin_menu_activate), pluginData);
 }
